# 5.3.3.1 Formas de pago

FormaPago = {
  '1': '1 - Contado'
}

# 5.3.3.2 Medios de pago

MedioPago = {
    "1": "1 Instrumento no definido ",
    "40": "40 Débito Negocio Intercambio Corporativo (CTX)",
    "2": "2 Crédito ACH ",
    "41": "41 Concentración efectivo/Desembolso Crédito plus (CCD+)  ",
    "3": "3 Débito ACH ",
    "42": "42 Consignación bancaria",
    "4": "4 Reversión débito de demanda ACH ",
    "43": "43 Concentración efectivo / Desembolso Débito plus (CCD+)",
    "5": "5 Reversión crédito de demanda ACH   ",
    "44": "44 Nota cambiaria",
    "6": "6 Crédito de demanda ACH ",
    "45": "45 Transferencia Crédito Bancario",
    "7": "7 Débito de demanda ACH ",
    "46": "46 Transferencia Débito Interbancario",
    "8": "8 Mantener ",
    "47": "47 Transferencia Débito Bancaria",
    "9": "9 Clearing Nacional o Regional ",
    "48": "48 Tarjeta Crédito",
    "10": "10 Efectivo ",
    "49": "49 Tarjeta Débito",
    "11": "11 Reversión Crédito Ahorro ",
    "50": "50 Postgiro",
    "12": "12 Reversión Débito Ahorro ",
    "51": "51 Telex estándar bancario francés",
    "13": "13 Crédito Ahorro ",
    "52": "52 Pago comercial urgente",
    "14": "14 Débito Ahorro ",
    "53": "53 Pago Tesorería Urgente",
    "15": "15 Bookentry Crédito ",
    "60": "60 Nota promisoria",
    "16": "16 Bookentry Débito ",
    "61": "61 Nota promisoria firmada por el acreedor",
    "17": "17 Concentración de la demanda en efectivo /Desembolso Crédito (CCD) ",
    "62": "62 Nota promisoria firmada por el acreedor, avalada por el banco",
    "18": "18 Concentración de la demanda en efectivo / Desembolso (CCD) débito ",
    "63": "63 Nota promisoria firmada por el acreedor, avalada por un tercero",
    "19": "19 Crédito Pago negocio corporativo (CTP) ",
    "64": "64 Nota promisoria firmada por el banco",
    "20": "20 Cheque ",
    "65": "65 Nota promisoria firmada por un banco avalada por otro banco",
    "21": "21 Proyecto bancario ",
    "66": "66 Nota promisoria firmada  ",
    "22": "22 Proyecto bancario certificado ",
    "67": "67 Nota promisoria firmada por un tercero avalada por un banco",
    "23": "23 Cheque bancario ",
    "70": "70 Retiro de nota por el por el acreedor",
    "24": "24 Nota cambiaria esperando aceptación ",
    "71": "71 Bonos",
    "25": "25 Cheque certificado ",
    "72": "72 Vales",
    "26": "26 Cheque Local ",
    "74": "74 Retiro de nota por el por el acreedor sobre un banco",
    "27": "27 Débito Pago Negocio Corporativo (CTP) ",
    "75": "75 Retiro de nota por el acreedor, avalada por otro banco",
    "28": "28 Crédito Negocio Intercambio Corporativo (CTX) ",
    "76": "76 Retiro de nota por el acreedor, sobre un banco avalada por un tercero",
    "29": "29 Débito Negocio Intercambio Corporativo (CTX) ",
    "77": "77 Retiro de una nota por el acreedor sobre un tercero",
    "30": "30 Transferencia Crédito ",
    "78": "78 Retiro de una nota por el acreedor sobre un tercero avalada por un banco",
    "31": "31 Transferencia Débito ",
    "91": "91 Nota bancaria transferible",
    "32": "32 Concentración Efectivo / Desembolso Crédito plus (CCD+) ",
    "92": "92 Cheque local trasferible",
    "33": "33 Concentración Efectivo / Desembolso Débito plus (CCD+) ",
    "93": "93 Giro referenciado",
    "34": "34 Pago y depósito pre acordado (PPD) ",
    "94": "94 Giro urgente",
    "35": "35 Concentración efectivo ahorros / Desembolso Crédito (CCD) ",
    "95": "95 Giro formato abierto",
    "36": "36 Concentración efectivo ahorros / Desembolso Crédito (CCD) ",
    "96": "96 Método de pago solicitado no usado",
    "37": "37 Pago Negocio Corporativo Ahorros Crédito (CTP) ",
    "97": "97 Clearing entre partners",
    "38": "38 Pago Negocio Corporativo Ahorros Débito (CTP) ",
    "98": "98 Cuentas de Ahorro de Tramite Simplificado (CATS)(Nequi, Daviplata, etc)",
    "39": "39 Crédito Negocio Intercambio Corporativo (CTX) ZZZ Acuerdo mutuo",
}






import unittest
from docedian import utils

class TestUtilsMethods(unittest.TestCase):

    def test_compute_vat_vd(self):
        """
        Test the compute vat vd method
        """

        self.assertEqual(utils.compute_vat_vd('901079560'), '1')
        self.assertEqual(utils.compute_vat_vd('900495672'), '8')
        self.assertEqual(utils.compute_vat_vd('901025526'), '9')
        self.assertEqual(utils.compute_vat_vd('901250040'), '5')
        self.assertEqual(utils.compute_vat_vd('900952931'), '1')



# -*- coding: utf-8 -*-


def compute_vat_vd(rut):
    """
    :param rut(str): rut to check
    
    Obtiene el digito de verificacion de un rut

    :return result(str): vat vd
    """
    result = None
    factores = [3, 7, 13, 17, 19, 23, 29, 37, 41, 43, 47, 53, 59, 67, 71]
    rut_ajustado=str(rut).rjust( 15, '0')
    s = sum(int(rut_ajustado[14-i]) * factores[i] for i in range(14)) % 11
    if s > 1:
        result =  11 - s
    else:
        result = s

    return str(result)


# -*- coding: utf-8 -*-


# PaymentMeansCode
# 13.2.11. Medios de Pago: cbc:PaymentMeansCode 
# Código Medio
PaymentMeansCode = {
    '10': '01 - Efectivo',
    '48': '48 - Tarjeta Crédito',
    '49': '49 - Tarjeta Débito',
    '47': '47 - Transferencia Débito Bancaria',
    '42': '42 - Consiganción bancaria',
    '44': '44 - Nota cambiaria',
    '3': '3 - Débito ACH',
    '20': '20 - Cheque',
    '25': '25 - Cheque certificado',
    '23': '23 - Cheque bancario de gerencia',
    '26': '26 - Cheque Local',
    '71': '71 - Bonos',
    '24': '24 - Vales',
    '64': '64 - Nota promisoria firmada pro el banco',
    '61': '61 - Nota promisoria firmada por el acreedor',
    '65': '65 - Nota promisoria firmada por un banco avalada porotro banco',
    '62': '62 - Nota promisoria firmada por el acreedor, avalada por el banco',
    '66': '66 - Nota promisoria firmada ',
    '63': '63 - Nota promisoria firmada por el acreedor, avalada por un tercero',
    '67': '67 - Nota promisoria firmada por un tercero avalada por un banco',
    '60': '60 - Nota promisoria',
    '2': '2 - Crédito ACH',
    '96': '96 - Método de pago solicitado no usuado',
    'ZZZ': 'ZZZ - Otro* ',
    '91': '91 - Nota bancaria transferible',
    '95': '95 - Giro formato abierto',
    '92': '92 - Cheque local transferible',
    '13': '13 - Crédito Ahorro',
    '93': '93 - Giro referenciado',
    '14': '14 - Débito Ahorro',
    '94': '94 - Giro urgente',
    '39': '39 - Crédito Intercambio Corporativo (CTX) ',
    '40': '40 - Débito Intercambio Corporativo (CTX)',
    '4': '4 - Reversión débito de demanda ACH ',
    '41': '41 - Desembolso Crédito plus (CCD+)',
    '5': '5 - Reversión crédito de demanda ACH ',
    '43': '43 - Desembolso Débito plus (CCD+) ',
    '6': '6 - Crédito de demanda ACH ',
    '45': '45 - Transferencia Crédito Bancario ',
    '7': '7 - Débito de demanda ACH ',
    '46': '46 - Transferencia Débito Bancario ',
    '9': '9 - Clearing Nacional o Regional ',
    '50': '50 - Postgiro ',
    '11': '11 - Reversión Crédito Ahorro ',
    '51': '51 - Telex estándar bancario ',
    '12': '12 - Reversión Débito Ahorro ',
    '52': '52 - Pago comercial urgente ',
    '18': '18 - Desembolso (CCD) débito ',
    '53': '53 - Pago Tesorería Urgente',
    '19': '19 - Crédito Pago negocio corporativo (CTP) ',
    '15': '15 - Bookentry Crédito',
    '21': '21 - Poyecto bancario 16 Bookentry Débito',
    '22': '22 - Proyecto bancario certificado ',
    '17': '17 - Desembolso Crédito (CCD)',
    '27': '27 - Débito Pago Neogcio Corporativo (CTP) ',
    '70': '70 - Retiro de nota por el por el acreedor',
    '28': '28 - Crédito Negocio Intercambio Corporativo (CTX) ',
    '74': '74 - Retiro de nota por el por el acreedor sobre un banco',
    '29': '29 - Débito Negocio Intercambio Corporativo (CTX) ',
    '75': '75 - Retiro de nota por el acreedor, avalada por otro banco',
    '30': '30 - Transferencia Crédito ',
    '76': '76 - Retiro de nota por el acreedor, sobre un banco avalada por un tercero',
    '31': '31 - Transferencia Débito ',
    '77': '77 - Retiro de una nota por el acreedor sobre un tercero',
    '32': '32 - Desembolso Crédito plus (CCD+) ',
    '78': '78 - Retiro de una nota por el acreedor sobre un tercero avalada por un banco',
    '33': '33 - Desembolso Débito plus (CCD+) ',
    '1 ': '1  - Instrumento no definido',
    '34': '34 - Pago y depósito pre acordado (PPD) ',
    '37': '37 - Pago Negocio Corporativo Ahorros Crédito (CTP)',
    '35': '35 - Desembolso Crédito (CCD) ',
    '38': '38 - Pago Negocio Corporativo Ahorros Débito (CTP)',
    '36': '36 - Desembolso Débito (CCD) ',
    '97': '97 - Clearing entre partners',
        
}


# 13.2.12. Ambiente de Destino del Documento: cbc:ProfileExecutionID y cbc:UUID/@schemeID 
# Código de Ambiente


# 13.2.13. Documento de identificación (Tipo de Identificador Fiscal): @schemeName
# Código de Identificador Fiscal



# 13.2.14. Tipo de organización jurídica (Personas): cbc:AdditionalAccountID 
# Código de Organización Jurídica
OrganizationType = {
    '1': '1 - Persona Jurídica y asimiladas',
    '2': '2 - Persona Natural y asimiladas',
}

# 13.2.15. Para el grupo TaxScheme
# Código de Tipo de Impuesto
TaxTypeCode = {
'01': '01 - IVA',
'04': '04 - INC',
'ZA': 'ZA - IVA e INC',
'ZZ (*)': 'ZZ (*) - No aplica',
}


from setuptools import setup, find_packages
import codecs
import os

VERSION = '0.1.0'
DESCRIPTION = 'Modulo con definiciones de la DIAN'

PACKAGE_NAME = "docedian"

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name=PACKAGE_NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description_content_type='text/markdown',
    long_description=long_description,
    url='https://github.com/pedroporras/dian_technical_data',
    author='Pedro Porras',
    author_email='<pedroporras@inexpresivo.com>',
    keywords=['DIAN', 'Colombia'],
    license='LGPL',
    packages=find_packages(),
    install_requires = [],
    extras_require = {
        'dev': [],
        'test': [],
    },
)



Ambiente = {
    '1': '1 - Produccion',
    '2': '2 - Pruebas',
}


TipoDocumento = {
    '11': '11 - Registro civil',
    '12': '12 - Tarjeta de identidad',
    '13': '13 - Cédula de ciudadanía',
    '21': '21 - Tarjeta de extranjería',
    '22': '22 - Cédula de extranjería',
    '31': '31 - NIT',
    '41': '41 - Pasaporte',
    '42': '42 - Documento de identificación extranjero',
    '47': '47 - PEP',
    '50': '50 - NIT de otro país',
    '91': '91 - NUIP * ',
}